==> adx-common-2.7.7.1-sources.jar: com/bxm/adx/common/buy/buyer/AbstractHttpBuyer.java <==
package com.bxm.adx.common.buy.buyer;

import com.bxm.adx.common.AdxProperties;
import com.bxm.adx.common.buy.dsp.Dsp;
import com.bxm.adx.facade.constant.enums.AdxErrEnum;
import com.bxm.adx.facade.exception.AdxException;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections.MapUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.http.HttpEntity;
import org.apache.http.HttpResponse;
import org.apache.http.client.HttpClient;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.client.methods.HttpUriRequest;
import org.apache.http.conn.ConnectTimeoutException;
import org.apache.http.conn.ConnectionPoolTimeoutException;
import org.apache.http.entity.ByteArrayEntity;
import org.apache.http.util.EntityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;

import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.SocketTimeoutException;
import java.net.URLEncoder;
import java.util.Map;
import java.util.Objects;

/**
 * 抽象的 Http 协议买家实现。
 *
 * @author allen
 * @since 2019-12-13
 */
@Slf4j
public abstract class AbstractHttpBuyer extends AbstractBuyer {

    private final AdxProperties properties;
    private com.bxm.adx.common.buy.buyer.HttpClientBuilder httpClientBuilder;

    public AbstractHttpBuyer(AdxProperties properties) {
        this.properties = properties;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        AbstractHttpBuyer that = (AbstractHttpBuyer) o;
        String code = getCode();
        return Objects.equals(code, that.getCode());
    }

    @Override
    public int hashCode() {
        return Objects.hash(getCode());
    }

    /**
     * 返回请求地址
     *
     * @return URL
     */
    protected String getUri() {
        Dsp dsp = getDsp();
        return dsp.getApiUrl();
    }

    /**
     * 返回请求Header
     *
     * @return Headers
     */
    protected Map<String, String> getHeaders() {
        return null;
    }

    /**
     * 返回请求方式
     *
     * @return 请求方式
     */
    protected Method getMethod() {
        return Method.POST;
    }

    @Override
    protected byte[] request(byte[] requestBody) {
        try {
            HttpClient httpClient = buildHttpClient();
            String uri = getUri();
            if (StringUtils.isBlank(uri)) {
                throw new NullPointerException("uri");
            }
            Map<String, String> headers = getHeaders();
            HttpUriRequest request =
                    getMethod() == Method.GET
                            ? buildGet(uri, headers, RequestBodyCodec.convert(requestBody))
                            : buildPost(uri, headers, requestBody);
            HttpResponse httpResponse = httpClient.execute(request);
            HttpEntity httpEntity = httpResponse.getEntity();
            if (httpEntity == null) {
                return null;
            }
            byte[] bytes = EntityUtils.toByteArray(httpEntity);
            log.debug("request:{},response:{} ", new String(requestBody), new String(bytes));

            int code = httpResponse.getStatusLine().getStatusCode();
            HttpStatus status = HttpStatus.resolve(code);
            if (!status.is2xxSuccessful()) {
                //非正常响应
                buyerMeter.increaseHttpStatusUn2XX(this);
                return null;
            }

            return bytes;
        } catch (IOException e) {
            log.debug("request: {}", e.getMessage());
            if (e instanceof SocketTimeoutException) {
                // 读取超时
                buyerMeter.increaseReadException(this);
            } else if (e instanceof ConnectTimeoutException) {
                // 连接超时
                buyerMeter.increaseConnectException(this);
            }
            throw new AdxException(AdxErrEnum.DSP_TIMEOUT);
        } catch (NullPointerException e) {
            log.info("request: ", e);
        } catch (Exception e) {
            log.warn("request: ", e);
        }
        return null;
    }

    protected HttpClient buildHttpClient() {
        return httpClientBuilder.build(getDsp());
    }

    protected HttpGet buildGet(String uri, Map<String, String> headers, Map<String, Object> params) {
        HttpGet get = new HttpGet(appendUrlEncodeParameterToUrl(params, uri));
        if (MapUtils.isNotEmpty(headers)) {
            for (Map.Entry<String, String> entry : headers.entrySet()) {
                get.addHeader(entry.getKey(), entry.getValue());
            }
        }

        return get;
    }

    protected HttpPost buildPost(String uri, Map<String, String> headers, byte[] requestBody) {
        HttpPost post = new HttpPost(uri);
        post.setEntity(new ByteArrayEntity(requestBody));
        if (MapUtils.isNotEmpty(headers)) {
            for (Map.Entry<String, String> entry : headers.entrySet()) {
                post.addHeader(entry.getKey(), entry.getValue());
            }
        }
        return post;
    }

    protected String appendParameterToUrl(Map<String, Object> params, String url) {
        StringBuilder uri = new StringBuilder(255);
        if (!StringUtils.endsWith(url, "?")) {
            uri.append("?");
        }
        for (Map.Entry<String, Object> entry : params.entrySet()) {
            String key = entry.getKey();
            Object value = entry.getValue();
            if (StringUtils.isNotBlank(key) && Objects.nonNull(value)) {
                uri.append(key).append("=").append(value).append("&");
            }
        }
        url += StringUtils.removeEnd(uri.toString(), "&");
        return url;
    }

    protected String appendUrlEncodeParameterToUrl(Map<String, Object> params, String url) {
        StringBuilder uri = new StringBuilder(255);
        if (!StringUtils.endsWith(url, "?")) {
            uri.append("?");
        }
        for (Map.Entry<String, Object> entry : params.entrySet()) {
            String key = entry.getKey();
            Object value = entry.getValue();
            if (StringUtils.isNotBlank(key) && Objects.nonNull(value)) {
                try {
                    uri.append(key).append("=").append(URLEncoder.encode(value.toString(), "UTF-8")).append("&");
                } catch (UnsupportedEncodingException e) {
                    log.error("build get uri err");
                }
            }
        }
        url += StringUtils.removeEnd(uri.toString(), "&");
        return url;
    }

    @Autowired
    public void setHttpClientBuilder(com.bxm.adx.common.buy.buyer.HttpClientBuilder httpClientBuilder) {
        this.httpClientBuilder = httpClientBuilder;
    }

    public enum Method {
        /**
         * Get method
         */
        GET,
        /**
         * Post method
         */
        POST
    }
}

==> adx-common-2.7.9.24-sources.jar: com/bxm/adx/common/buy/buyer/AbstractHttpBuyer.java <==
package com.bxm.adx.common.buy.buyer;

import com.bxm.adx.common.AdxProperties;
import com.bxm.adx.common.buy.dsp.Dsp;
import com.bxm.adx.facade.constant.enums.AdxErrEnum;
import com.bxm.adx.facade.exception.AdxException;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections.MapUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.http.HttpEntity;
import org.apache.http.HttpResponse;
import org.apache.http.client.HttpClient;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.client.methods.HttpUriRequest;
import org.apache.http.conn.ConnectTimeoutException;
import org.apache.http.conn.ConnectionPoolTimeoutException;
import org.apache.http.entity.ByteArrayEntity;
import org.apache.http.util.EntityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;

import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.SocketTimeoutException;
import java.net.URLEncoder;
import java.util.Map;
import java.util.Objects;

/**
 * 抽象的 Http 协议买家实现。
 *
 * @author allen
 * @since 2019-12-13
 */
@Slf4j
public abstract class AbstractHttpBuyer extends AbstractBuyer {

    private final AdxProperties properties;
    private com.bxm.adx.common.buy.buyer.HttpClientBuilder httpClientBuilder;

    public AbstractHttpBuyer(AdxProperties properties) {
        this.properties = properties;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        AbstractHttpBuyer that = (AbstractHttpBuyer) o;
        String code = getCode();
        return Objects.equals(code, that.getCode());
    }

    @Override
    public int hashCode() {
        return Objects.hash(getCode());
    }

    /**
     * 返回请求地址
     *
     * @return URL
     */
    protected String getUri() {
        Dsp dsp = getDsp();
        return dsp.getApiUrl();
    }

    /**
     * 返回请求Header
     *
     * @return Headers
     */
    protected Map<String, String> getHeaders() {
        return null;
    }

    /**
     * 返回请求方式
     *
     * @return 请求方式
     */
    protected Method getMethod() {
        return Method.POST;
    }

    @Override
    protected byte[] request(byte[] requestBody) {
        try {
            HttpClient httpClient = buildHttpClient();
            String uri = getUri();
            if (StringUtils.isBlank(uri)) {
                throw new NullPointerException("uri");
            }
            Map<String, String> headers = getHeaders();
            HttpUriRequest request =
                    getMethod() == Method.GET
                            ? buildGet(uri, headers, RequestBodyCodec.convert(requestBody))
                            : buildPost(uri, headers, requestBody);
            HttpResponse httpResponse = httpClient.execute(request);
            HttpEntity httpEntity = httpResponse.getEntity();
            if (httpEntity == null) {
                return null;
            }
            byte[] bytes = EntityUtils.toByteArray(httpEntity);
            log.debug("request:{},response:{} ", new String(requestBody), new String(bytes));

            int code = httpResponse.getStatusLine().getStatusCode();
            HttpStatus status = HttpStatus.resolve(code);
            if (Objects.nonNull(status) && !status.is2xxSuccessful()) {
                //非正常响应
                buyerMeter.increaseHttpStatusUn2XX(this);
                return null;
            }

            return bytes;
        } catch (IOException e) {
            log.debug("request: {}", e.getMessage());
            if (e instanceof SocketTimeoutException) {
                // 读取超时
                buyerMeter.increaseReadException(this);
            } else if (e instanceof ConnectTimeoutException) {
                // 连接超时
                buyerMeter.increaseConnectException(this);
            }
            throw new AdxException(AdxErrEnum.DSP_TIMEOUT);
        } catch (NullPointerException e) {
            log.info("request: ", e);
        } catch (Exception e) {
            log.warn("request: ", e);
        }
        return null;
    }

    protected HttpClient buildHttpClient() {
        return httpClientBuilder.build(getDsp());
    }

    protected HttpGet buildGet(String uri, Map<String, String> headers, Map<String, Object> params) {
        HttpGet get = new HttpGet(appendUrlEncodeParameterToUrl(params, uri));
        if (MapUtils.isNotEmpty(headers)) {
            for (Map.Entry<String, String> entry : headers.entrySet()) {
                get.addHeader(entry.getKey(), entry.getValue());
            }
        }

        return get;
    }

    protected HttpPost buildPost(String uri, Map<String, String> headers, byte[] requestBody) {
        HttpPost post = new HttpPost(uri);
        post.setEntity(new ByteArrayEntity(requestBody));
        if (MapUtils.isNotEmpty(headers)) {
            for (Map.Entry<String, String> entry : headers.entrySet()) {
                post.addHeader(entry.getKey(), entry.getValue());
            }
        }
        return post;
    }

    protected String appendParameterToUrl(Map<String, Object> params, String url) {
        StringBuilder uri = new StringBuilder(255);
        if (!StringUtils.endsWith(url, "?")) {
            uri.append("?");
        }
        for (Map.Entry<String, Object> entry : params.entrySet()) {
            String key = entry.getKey();
            Object value = entry.getValue();
            if (StringUtils.isNotBlank(key) && Objects.nonNull(value)) {
                uri.append(key).append("=").append(value).append("&");
            }
        }
        url += StringUtils.removeEnd(uri.toString(), "&");
        return url;
    }

    protected String appendUrlEncodeParameterToUrl(Map<String, Object> params, String url) {
        StringBuilder uri = new StringBuilder(255);
        if (!StringUtils.endsWith(url, "?")) {
            uri.append("?");
        }
        for (Map.Entry<String, Object> entry : params.entrySet()) {
            String key = entry.getKey();
            Object value = entry.getValue();
            if (StringUtils.isNotBlank(key) && Objects.nonNull(value)) {
                try {
                    uri.append(key).append("=").append(URLEncoder.encode(value.toString(), "UTF-8")).append("&");
                } catch (UnsupportedEncodingException e) {
                    log.error("build get uri err");
                }
            }
        }
        url += StringUtils.removeEnd(uri.toString(), "&");
        return url;
    }

    @Autowired
    public void setHttpClientBuilder(com.bxm.adx.common.buy.buyer.HttpClientBuilder httpClientBuilder) {
        this.httpClientBuilder = httpClientBuilder;
    }

    public enum Method {
        /**
         * Get method
         */
        GET,
        /**
         * Post method
         */
        POST
    }
}
